summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/assocpropdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/assocpropdlg.h')
-rw-r--r--umbrello/umbrello/dialogs/assocpropdlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/assocpropdlg.h b/umbrello/umbrello/dialogs/assocpropdlg.h
index 359add61..10fe344b 100644
--- a/umbrello/umbrello/dialogs/assocpropdlg.h
+++ b/umbrello/umbrello/dialogs/assocpropdlg.h
@@ -36,12 +36,12 @@ public:
/**
* Sets up a Association Properties Dialog.
* @param tqparent The tqparent of the AssocPropDlg
* @param a The Association Widget to display properties of.
* @param pageNum The page to show first.
*/
- AssocPropDlg(TQWidget *tqparent, AssociationWidget *a, int pageNum = 0);
+ AssocPropDlg(TQWidget *parent, AssociationWidget *a, int pageNum = 0);
/**
* Standard deconstructor
@@ -36,12 +36,12 @@ public:
/**
* Sets up a Association Properties Dialog.
- * @param tqparent The tqparent of the AssocPropDlg
+ * @param parent The parent of the AssocPropDlg
* @param a The Association Widget to display properties of.
* @param pageNum The page to show first.